Struct abstract_core::manager::RegisterModuleData
source · pub struct RegisterModuleData {
pub module_address: String,
pub module: Module,
}Fields
module_address: Stringmodule: ModuleTrait Implementations
sourceimpl Clone for RegisterModuleData
impl Clone for RegisterModuleData
sourcefn clone(&self) -> RegisterModuleData
fn clone(&self) -> RegisterModuleData
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for RegisterModuleData
impl Debug for RegisterModuleData
sourceimpl<'de> Deserialize<'de> for RegisterModuleData
impl<'de> Deserialize<'de> for RegisterModuleData
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for RegisterModuleData
impl JsonSchema for RegisterModuleData
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq for RegisterModuleData
impl PartialEq for RegisterModuleData
sourcefn eq(&self, other: &RegisterModuleData) -> bool
fn eq(&self, other: &RegisterModuleData) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for RegisterModuleData
impl Serialize for RegisterModuleData
impl StructuralPartialEq for RegisterModuleData